% set up frequencies
fmin = -1;
fmax = 3;
f = logspace(fmin,fmax,1000);

% open loop gain

tf_freerun    = model_sys(5,1); % In1 to Out5
tf_stability  = model_sys(4,1); % In1 to Out4
tf_err        = model_sys(1,1); % In1 to Out4

g_freerun   = mybodesys(tf_freerun, f);
g_stability = mybodesys(tf_stability, f);
g_err       = mybodesys(tf_err,f);

x_seis = 1e-7./f'.^2;

x_freerun   = abs(g_freerun).*x_seis;
x_stability = abs(g_stability).*x_seis;
x_err       = abs(g_err).*x_seis/Gsens; % Error signal calibration

clf;
loglog(f,x_freerun,'r', 'LineWidth',2);
hold on;
loglog(f,x_stability,'b', 'LineWidth',2);
loglog(f,x_err,      'g', 'LineWidth',2);
loglog(f,x_seis,     'k--', 'LineWidth',1);
set(gca,'FontSize',14);
set(gca,'GridLineStyle','--');
set(gca,'Color',[1 1 1])
grid on;
%ylim([1e-4 1e2]);
legend(...
    'Freerun (=unsuppressed)',...
    'Stabilized (=suppressed)',...
    'Sensed motion (from Verr)',...
    'Ground motion',...
    'Location', 'NorthEast'...
);
title('Suspension displacement');
xlabel('Frequency (Hz)');
ylabel('Displacement noise (m/rtHz)');

orient landscape;
% print -dpdf 'Model_SUS_resp.pdf'